@@ -7,6 +7,9 @@ class AbstractApplication(ABC):
 
     def __init__(self, service):
         self.service = service
+
+    def get_all (self):
+        return self.service.get_all()
         
     def create(self, object):
         self.service.create (object)
