@@ -11,7 +11,7 @@ class BaseService():
         self.type = self.object.__tablename__
     
     def get_all(self):
-        return self.session.query(self.object).order_by(self.object.id)
+        return self.session.query(self.object).order_by(self.object.id).all()
     
     def get_by_uuid(self, uuid):
         return self.session.query(self.object).filter(self.object.uuid == uuid).first()
